'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return Object.freeze(n);
}

var React__namespace = /*#__PURE__*/_interopNamespace(React);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

class ExplainDataManager extends EventTarget {
  constructor() {
    super();
    this.explainData = [];
  }
  getExplainData() {
    return this.explainData
  }

  setExplain(explainData) {
    this.explainData = explainData || [];
    this.dispatchEvent(new Event('updateExplainData'));
  }
}

const explainDataManager = new ExplainDataManager();

const useExplain = () => {
  const [explain, setExplain] = React.useState(explainDataManager.getExplainData());
  const [defaultExplain, setDefaultExplain] = React.useState(
    explainDataManager.getExplainData()
  );
  const [pathOrder, setPathOrder] = React.useState(0);
  const [timeOrder, setTimeOrder] = React.useState(0);

  React.useEffect(() => {
    const eventListener = explainDataManager.addEventListener(
      'updateExplainData',
      (e, value) => {
        setDefaultExplain(() => e.target.explainData || []);
        setExplain(_ => e.target.explainData || []);
      }
    );
    return () => {
      explainDataManager.removeEventListener('updateExplainData', eventListener);
    }
  }, []);

  const searchByField = React.useCallback(
    fieldName => {
      return event => {
        setExplain(_ => {
          return defaultExplain.filter(element => {
            return element[fieldName].includes(event.target.value)
          })
        });
      }
    },
    [defaultExplain]
  );

  const sort = React.useCallback(
    (fieldName = 'path') => {
      return order => {
        let localOrder = order;
        if (!order || order === 0) {
          return explain
        } else if (order >= 1) {
          localOrder = 1;
        } else {
          localOrder = -1;
        }
        setExplain(_ => {
          return explain.sort((a, b) => {
            return (
              localOrder * `${a[fieldName]}`.localeCompare(`${b[fieldName]}`)
            )
          })
        });
      }
    },
    [explain]
  );

  const sortPath = sort('path');
  const sortTime = sort('time');

  const changePathOrder = React.useCallback(() => {
    if (pathOrder !== 0) {
      setPathOrder(prev => -prev);
    } else {
      setPathOrder(1);
    }
    setTimeOrder(0);
  }, [pathOrder]);

  const changeTimeOrder = React.useCallback(() => {
    if (timeOrder !== 0) {
      setTimeOrder(prev => -prev);
    } else {
      setTimeOrder(1);
    }
    setPathOrder(0);
  }, [timeOrder]);
  React.useEffect(() => {
    sortPath(pathOrder);
  }, [pathOrder, sortPath]);

  React.useEffect(() => {
    sortTime(timeOrder);
  }, [timeOrder, sortTime]);

  return {
    explain,
    searchByPath: searchByField('path'),
    changePathOrder,
    changeTimeOrder,
    timeOrder,
    pathOrder
  }
};

var _path;
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
var SvgArrow = function SvgArrow(props) {
  return /*#__PURE__*/React__namespace.createElement("svg", _extends({
    height: 32,
    width: 32,
    xmlSpace: "preserve",
    xmlns: "http://www.w3.org/2000/svg",
    role: "img"
  }, props), _path || (_path = /*#__PURE__*/React__namespace.createElement("path", {
    d: "m18.221 7.206 9.585 9.585a2.265 2.265 0 0 1 0 3.195l-.8.801a2.266 2.266 0 0 1-3.194 0l-7.315-7.315-7.315 7.315a2.266 2.266 0 0 1-3.194 0l-.8-.801a2.265 2.265 0 0 1 0-3.195l9.587-9.585a2.24 2.24 0 0 1 1.723-.647 2.247 2.247 0 0 1 1.723.647z",
    fill: "#515151"
  })));
};

function Content() {
  const {
    explain,
    searchByPath,
    changePathOrder,
    changeTimeOrder,
    timeOrder,
    pathOrder
  } = useExplain();

  return (
    React__default["default"].createElement('div', {style: { height: '100%'}}, [
      React__default["default"].createElement('input', {type: "text", onChange: searchByPath, placeholder: "Search by path"}),
      React__default["default"].createElement('table', {style: { width: '100%'}}, [
        React__default["default"].createElement('thead', null, [
          React__default["default"].createElement('tr', null, [
            React__default["default"].createElement('th', {
              onClick: changePathOrder,
              style: { margin: 0, padding: 0, width: '50%'}
            }, [
              React__default["default"].createElement('div', {
                style: {
                  textAlign: 'left',
                  display: 'flex',
                  alignItems: 'center'
                }
              }, [
                React__default["default"].createElement('p', null, ["Path"]),
                pathOrder !== 0 && (
                  React__default["default"].createElement('img', {
                    src: SvgArrow,
                    style: {
                      height: '20px',
                      // width: '20px',
                      margin: 0,
                      rotate: pathOrder > 0 ? '0deg' : '180deg'
                    },
                    alt: `arrow-${pathOrder > 0 ? 'up' : 'down'}`}
                  )
                )
              ])
            ]),
            React__default["default"].createElement('th', {
              onClick: changeTimeOrder,
              style: { margin: 0, padding: 0, width: '50%'}
            }, [
              React__default["default"].createElement('div', {
                style: {
                  textAlign: 'left',
                  display: 'flex',
                  alignItems: 'center'
                }
              }, [
                React__default["default"].createElement('p', null, ["Time(ms)"]),
                timeOrder !== 0 && (
                  React__default["default"].createElement('img', {
                    src: SvgArrow,
                    style: {
                      // height: '20px',
                      width: '20px',

                      rotate: timeOrder > 0 ? '0deg' : '180deg'
                    },
                    alt: `arrow-${timeOrder > 0 ? 'up' : 'down'}`}
                  )
                )
              ])
            ])
          ])
        ]),
        React__default["default"].createElement('tbody', null, [
          explain && explain.length > 0 ? (
            explain.map(e => {
              return (
                React__default["default"].createElement('tr', {key: e.path}, [
                  React__default["default"].createElement('td', null, [e.path]),
                  React__default["default"].createElement('td', null, [(e.time * 1e-6).toFixed(2), " "])
                ])
              )
            })
          ) : (
            React__default["default"].createElement('tr', null, [
              React__default["default"].createElement('td', null, ["No entry found"])
            ])
          )
        ])
      ])
    ])
  )
}
function Icon() {
  return React__default["default"].createElement('p', null, ["GE"])
}

function graphiqlExplainPlugin() {
  return umdPlugin()
}

function umdPlugin() {
  return {
    title: 'GraphiQL Explain',
    icon: () => Icon(),
    content: () => {
      return Content()
    }
  }
}

function saveExplainResponse(data) {
  const { explain } = data.extensions || {};

  if (explain && explain.profiler.data) {
    explainDataManager.setExplain(explain.profiler.data);
  }
  return data
}

function parseExplainResponse(data) {
  return saveExplainResponse(data)
}

exports.graphiqlExplainPlugin = graphiqlExplainPlugin;
exports.parseExplainResponse = parseExplainResponse;
exports.umdPlugin = umdPlugin;
//# sourceMappingURL=index.js.map
